package cmd

import (
	"encoding/json"
	"fmt"

	"github.com/invopop/jsonschema"
	"github.com/spf13/cobra"
	"gitlab.chromabits.com/etcinit/butane-jsonschema/config"
)

var variant string
var version string

var genCmd = &cobra.Command{
	Use:   "gen",
	Short: "Generate and output a JSONSchema for the specified variant and version",
	Run: func(cmd *cobra.Command, args []string) {
		// Do Stuff Here
		variantMap := config.GetVariantMap()

		versionMap, exists := variantMap[variant]
		if !exists {
			fmt.Println("Unknown variant ", variant)
			return
		}

		config, exists := versionMap[version]
		if !exists {
			fmt.Println("Unknown version ", variant, " for ", variant)
			return
		}

		schema := jsonschema.Reflect(config)

		schema_data, err := json.MarshalIndent(schema, "", "  ")
		if err != nil {
			panic(err.Error())
		}
		fmt.Println(string(schema_data))
	},
}
